# -----------------------------------------------------------------------------
sub orantPerf2
# -----------------------------------------------------------------------------
{
  #----
  #---- This routine uses stacked data
  #----

  ($thishost) = @_;

  my $perf_other_rows = ""; 
  my $perf_vlf_rows = ""; 
  my $debug_perf = 0; 
  my $perf_event_count = 0; 
  my $this_metric = ""; 
  my $this_perf_label = ""; 
  my $zlabel = ""; 

  if ($up[$thishost] ne "Y")
  {
    &logit("(Down/Inhibited)",$thishost);
    return 1;
  }

  if (&check_inhib($thishost) eq "Y")
  {
    $up[$thishost] = "I";
    return;
  }

  #---- Add some metrics that were previously saved in variables
  $perf_readings[$thishost]{"DBA_Instance_Dur_Secs"} = $instance_duration[$thishost] if $instance_duration[$thishost] > 0;

  #---- Clear vars
  my $drilldown_data = ""; 

  foreach $this_metric (sort keys %{ $perf_readings[$thishost] })
  {
    $perf_val = $perf_readings[$thishost]{$this_metric}; 
    print "DEBUG orantPerf - Found this_metric=$this_metric perf_val=$perf_val\n" if $debug_perf; 

    $met_key = uc "PERF_$this_metric"; 
    &metricsInsert("orantPerf()", $thishost, "$met_key", ".", $perf_val);

    if ($this_metric =~ /rate/i) 
    {
      $zdesc = "Rate Per Second";
    }
    else
    {
      $zdesc = "Current Value";
    }

    &metricsCurrent("orantPerf()",$thishost,"$met_key","",$perf_val,"","","$zdesc" );

    $this_metric_uc = uc $this_metric; 

    $zwarn = $t_perf_w[$thishost]{$this_metric_uc};
    $zcrit = $t_perf_c[$thishost]{$this_metric_uc};
    $zoperator = $t_perf_operator[$thishost]{$this_metric_uc};
    $zthresholds = "$zwarn/$zcrit"; 
    $zthresholds = " &nbsp; " if $zthresholds eq "/"; 

    #---- Decide on what we will do for PERF EVENT Severity
    if ($g_sqlperf_sev eq "Y") 
    {
      $sqlperf_sev_w = "P"; 
      $sqlperf_sev_c = "P"; 
    }
    else
    {
      $sqlperf_sev_w = "W"; 
      $sqlperf_sev_c = "C"; 
    }

    if ($t_perf_operator[$thishost]{$this_metric_uc})  #---- The OPERATOR would have a value if this one was specified
    {

      #---- Find label from DBC for this metric (if any)
      if ($perf_metric_label[$thishost]{$this_metric})
      {
	$zlabel          = "($perf_metric_label[$thishost]{$this_metric})" ; 
      }
      else
      {
	$zlabel          = ""; 
      }
    
      #---- LT LOGIC -- Check current reading against threshold 
      if ($t_perf_operator[$thishost]{$this_metric_uc} eq "LT")  #---- The OPERATOR would have a value if this one was specified
      {
	if ($perf_val < $t_perf_c[$thishost]{$this_metric_uc})
	{
	  &event($sqlperf_sev_c,$thishost,"PerfCounter $this_metric=$perf_val $zlabel - $zoperator CriticalThreshold=$zcrit","Perf-${this_metric}","DBA852");
	  $zcolor = "pink"; $perf_event_count++; 
	}
	elsif ($perf_val < $t_perf_w[$thishost]{$this_metric_uc})
	{
	  &event($sqlperf_sev_w,$thishost,"PerfCounter $this_metric=$perf_val $zlabel - $zoperator WarningThreshold=$zwarn","Perf-${this_metric}","DBA852");
	  $zcolor = "yellow"; $perf_event_count++; 
	}
	else { $zcolor = "lime"; }
      }
      #---- LE LOGIC -- Check current reading against threshold 
      elsif ($t_perf_operator[$thishost]{$this_metric_uc} eq "LE")  #---- The OPERATOR would have a value if this one was specified
      {
	if ($perf_val <= $t_perf_c[$thishost]{$this_metric_uc})
	{
	  &event($sqlperf_sev_c,$thishost,"PerfCounter $this_metric=$perf_val $zlabel - $zoperator CriticalThreshold=$zcrit","Perf-${this_metric}","DBA852");
	  $zcolor = "pink"; $perf_event_count++; 
	}
	elsif ($perf_val <= $t_perf_w[$thishost]{$this_metric_uc})
	{
	  &event($sqlperf_sev_w,$thishost,"PerfCounter $this_metric=$perf_val $zlabel - $zoperator WarningThreshold=$zwarn","Perf-${this_metric}","DBA852");
	  $zcolor = "yellow"; $perf_event_count++; 
	}
	else { $zcolor = "lime"; }
      }
      #---- GT LOGIC -- Check current reading against threshold 
      elsif ($t_perf_operator[$thishost]{$this_metric_uc} eq "GT")  #---- The OPERATOR would have a value if this one was specified
      {
	if ($perf_val > $t_perf_c[$thishost]{$this_metric_uc})
	{
	  &event($sqlperf_sev_c,$thishost,"PerfCounter $this_metric=$perf_val $zlabel - $zoperator CriticalThreshold=$zcrit","Perf-${this_metric}","DBA852");
	  $zcolor = "pink"; $perf_event_count++; 
	}
	elsif ($perf_val > $t_perf_w[$thishost]{$this_metric_uc})
	{
	  &event($sqlperf_sev_w,$thishost,"PerfCounter $this_metric=$perf_val $zlabel - $zoperator WarningThreshold=$zwarn","Perf-${this_metric}","DBA852");
	  $zcolor = "yellow"; $perf_event_count++; 
	}
	else { $zcolor = "lime"; }
      }
      #--- ELSE - Must be GE 
      else
      {
	if ($perf_val >= $t_perf_c[$thishost]{$this_metric_uc})
	{
	  &event($sqlperf_sev_c,$thishost,"PerfCounter $this_metric=$perf_val $zlabel - $zoperator CriticalThreshold=$zcrit","Perf-${this_metric}","DBA852");
	  $zcolor = "pink"; $perf_event_count++; 
	}
	elsif ($perf_val >= $t_perf_w[$thishost]{$this_metric_uc})
	{
	  &event($sqlperf_sev_w,$thishost,"PerfCounter $this_metric=$perf_val $zlabel - $zoperator WarningThreshold=$zwarn","Perf-${this_metric}","DBA852");
	  $zcolor = "yellow"; $perf_event_count++; 
	}
	else { $zcolor = "lime"; }
      }
    }
    else
    {
      #---- No threshold was specified for this metric
      $zcolor = "white"; 
    }

    #---- Find label from DBC for this metric (if any)
    if ($perf_metric_label[$thishost]{$this_metric})
    {
      $this_perf_label = "<br>($perf_metric_label[$thishost]{$this_metric})"; 
      $zlabel          = $perf_metric_label[$thishost]{$this_metric}; 
    }
    else
    {
      $this_perf_label = ""; 
      $zlabel          = ""; 
    }
  
    #---- Format WWW page entry: 
    $drilldown_data .=  "<tr>
      <td bgcolor=$zcolor>$f_s <b> $this_metric $this_perf_label </b>
      <td bgcolor=$zcolor align=right>$f_s <b> $perf_val </b>
      <td bgcolor=$zcolor align=right>$f_s <b> $zoperator $zthresholds </b> 
      <td>$f_s $zdesc 
      <td>$f_s &nbsp; <b>Charts - Recent: ( </b>
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,GRAW,$titleraw[$thishost],$met_key,.,$g_detail_retain_days,$zlabel'>   <b>L${g_detail_retain_days}D </b></a>  &nbsp; 
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,GRAW,$titleraw[$thishost],$met_key,.,7,$zlabel'>                       <b>L7D </b></a>  &nbsp;
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,GRAW,$titleraw[$thishost],$met_key,.,3,$zlabel'>                       <b>L3D </b></a>  
               <b>) Historical: </b>
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,GDAILY,$titleraw[$thishost],$met_key,.'> <b>(Daily)</b></a> &nbsp;
      <td>$f_s &nbsp; <b>Text/CSV - Recent: ( </b>
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,MDETAIL,$titleraw[$thishost],$met_key,.'><b>L${g_detail_retain_days}D </b></a> &nbsp; 
               <b>) Historical: </b>
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,MDAILY,$titleraw[$thishost],$met_key,.'><b>(Daily)</b></a> &nbsp;
    "; 
    #          <a href='/cgi-bin/dbamon_metrics.pl?$mode,GHOURLY,$titleraw[$thishost],$met_key,.'><b>Hourly (H)</b></a> &nbsp;
    #          <a href='/cgi-bin/dbamon_metrics.pl?$mode,MHOURLY,$titleraw[$thishost],$met_key,.'><b>Hourly (H)</b></a> &nbsp;

    #---- Save some possible readings for later (summarize.pl)
    if    ($this_metric eq "SYS_CPUTotalBusyPct")     { $reading_cpubusy_pct[$thishost]      = $perf_val; }
    elsif ($this_metric eq "SYS_MemUsedPct")          { $reading_memused_pct[$thishost]      = $perf_val; }
    elsif ($this_metric eq "SYS_DiskPhysAvgQueueLen") { $reading_diskqueuelen_avg[$thishost] = $perf_val; }
    elsif ($this_metric eq "SYS_DiskPhysAvgRTMS")     { $reading_diskrt_avg[$thishost]       = $perf_val; }
    elsif ($this_metric eq "SQL_Top_Waits_Rank1")     { $reading_topwait[$thishost]          = $perf_val; }
  }

  #---- WWW Details 
  print "DEBUG orantPerf - End of table\n" if $debug_perf; 

  &logDetails($thishost,"</table>");
  &logDetails($thishost,"<br><a name='orantPerf'> <h3>Oracle / Server Performance Readings</h3>");
  &logDetails($thishost,"<br><table border=1 bgcolor=$table_bgcolor>");
  &logDetails($thishost,"<tr bgcolor=$table_headbgcolor>
    <th>$f_s Metric
    <th>$f_s Current<br> Reading 
    <th>$f_s <a href='http://dbamon.com/config/dbc_mssql.shtml'>Comparison<br> Operator<br>Warning/Critical<br>Thresholds<br>(DBC:<br> T_PerfCounter:)</a>
    <th>$f_s Description 
    <th>$f_s Charts
    <th>$f_s Text/CSV Reports
  ");

  # <th>$f_s Graphs<br>(H)istorical Summarized<br>-or-<br>(R)aw Unsummarized 
  # <th>$f_s Text/CSV Reports<br>(H)istorical Summarized<br>-or-<br>(R)aw Unsummarized 

  &logDetails($thishost,$drilldown_data); 
  &logDetails($thishost,"</table><hr>");

  #&logDetails($thishost,"<br><h3>Other Performance Metrics</h3><table border=1 bgcolor=$table_bgcolor>");
  #&logDetails($thishost,"<tr bgcolor=$table_headbgcolor>
  #  <th>$f_s Metric
  #  <th>$f_s Current<br> Reading 
  #  <th>$f_s Threshold 
  #  <th>$f_s Description 
  #");
  #&logDetails($thishost,$perf_other_rows); 
  #&logDetails($thishost,"</table><hr>");

  &logit("OK - Total Performance Events this iteration: $perf_event_count",$thishost);

  return; 
}
# -----------------------------------------------------------------------------
1;
